@@ -60,13 +60,8 @@ class ImagePostModelAnalysis:
     def confusion_matrix(self, plot):
         if "class" not in self.images_data.problem_type:
             return None
-
-        # Replace predictions not in true labels with -1
-
-        # modified_eval_predictions = self.replace_predictions(eval_labels_unique=np.unique(self.eval_labels),
-        #                                                      eval_predictions=self.eval_predictions.numpy())
         try:
-            cm = confusion_matrix(self.eval_labels.cpu().numpy(), self.eval_predictions.numpy())
+            cm = confusion_matrix(self.eval_labels.cpu().numpy(), self.eval_predictions.cpu().numpy())
         except:
             cm = confusion_matrix(self.eval_labels, self.eval_predictions)
         self.diamond_collector["confusion matrix"] = cm
